package com.fs.sop.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.sop.domain.CompanySopRole;

/**
 * 公司SOP权限Mapper接口
 * 
 * @author fs
 * @date 2025-04-22
 */
public interface CompanySopRoleMapper extends BaseMapper<CompanySopRole>{
    /**
     * 查询公司SOP权限
     * 
     * @param id 公司SOP权限主键
     * @return 公司SOP权限
     */
    CompanySopRole selectCompanySopRoleById(Long id);

    /**
     * 查询公司SOP权限列表
     * 
     * @param companySopRole 公司SOP权限
     * @return 公司SOP权限集合
     */
    List<CompanySopRole> selectCompanySopRoleList(CompanySopRole companySopRole);

    /**
     * 新增公司SOP权限
     * 
     * @param companySopRole 公司SOP权限
     * @return 结果
     */
    int insertCompanySopRole(CompanySopRole companySopRole);

    /**
     * 修改公司SOP权限
     * 
     * @param companySopRole 公司SOP权限
     * @return 结果
     */
    int updateCompanySopRole(CompanySopRole companySopRole);

    /**
     * 删除公司SOP权限
     * 
     * @param id 公司SOP权限主键
     * @return 结果
     */
    int deleteCompanySopRoleById(Long id);

    /**
     * 批量删除公司SOP权限
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCompanySopRoleByIds(Long[] ids);
}
